@@ -4,8 +4,8 @@ from sqlconstructor import SqlWrap
 
 @pytest.mark.SqlWrap
 def test_add():
-    assert SqlWrap('a') + 'b' == '(\n  a\n)b'
+    assert str(SqlWrap('a') + 'b') == '(\n  a\n)b'
 
 @pytest.mark.SqlWrap
 def test_radd():
-    assert 'b' + SqlWrap('a') == 'b(\n  a\n)'
+    assert str('b' + SqlWrap('a')) == 'b(\n  a\n)'
